// Copyright 2017, the Flutter project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

part of firebase_database;

/// A DataSnapshot contains data from a Firebase Database location.
/// Any time you read Firebase data, you receive the data as a DataSnapshot.
class DataSnapshot {
  DataSnapshot._({
    this.key,
    this.value,
    this.valueInExportFormat,
    this.priority,
  });

  /// The key of the location that generated this DataSnapshot.
  final String key;

  /// Retrieves the contents of this data snapshot as native types.
  ///
  /// Doubles with integral values (e.g. 42.0) will be converted to `int`
  /// automatically. If you need a `double`, call `toDouble()` on
  /// the retrieved value or use [doubleValue] instead.
  final dynamic value;

  /// Retrieves the values and priorities of this data snapshot as native types.
  ///
  /// Doubles with integral values (e.g. 42.0) will be converted to `int`
  /// automatically. If you need a `double`, call `toDouble()` on
  /// the retrieved value or use [doubleValue] instead.
  final dynamic valueInExportFormat;

  /// Returns the priority of the data in this snapshot as a native type.
  ///
  /// If the priority is numeric it will be returned as a `double` rather than
  /// an `int`.
  final dynamic priority;

  /// Returns the contents of this snapshot as an `int`.
  int get intValue => (value as num)?.toInt();

  /// Returns the contents of this snapshot as an `double`.
  double get doubleValue => (value as num)?.toDouble();

  /// Returns the contents of this snapshot as a `String`.
  String get stringValue => value?.toString();

  Iterable<DataSnapshot> get children {
    if (value is Map) {

    } else if (value is List) {
      return new List.generate(value.length, (int index) {
        return new DataSnapshot._({ 'key': '$index', value: value[index]);
      });
    } else {
      return null;
    }
  }

  DataSnapshot child(String path) {
    assert(path != null);
    List<String> pathComponents = path.split("/");

    while(pathComponents.length > 0) {

    }
    return new DataSnapshot._(value[pathComponents[0]]);
  }
}
